# coding: utf-8
"""
Process a weather forecast json file to plot the time evolution of temperature
of a given day in a given city
"""
from urllib.request import urlopen
import json
import numpy
import matplotlib.pyplot as plt
import matplotlib.image as mpimg
from io import BytesIO


jsonfile_url = f"https://www.prevision-meteo.ch/services/json/Strasbourg"

try:
    f = urlopen(jsonfile_url, timeout=10)  # open url
except Exception:
    print("Le téléchargement a échoué : on lit une version locale.")
    f = open("exos/Strasbourg.json")

jsondict = json.loads(f.read())  # Read JSON file
day = jsondict['fcst_day_0']  # point the current day data
day_hd = day['hourly_data']

tempe = []

for hour, data in day_hd.items():
    tempe.append([int(hour[:-3]), data['TMP2m']])

tempe.sort()
t = numpy.array(tempe)
t = t.transpose()

# Plot T = T(hour)
fig, ax = plt.subplots()  # initialise figure and plot area
title = f"{day['day_long']} {day['date']}"
fig.suptitle(title, fontsize=14, fontweight='bold')
fig.subplots_adjust(top=0.85)

ax.set_title('Évolution horaire de la température')
ax.set_xlabel('Heure [h]')
ax.set_ylabel('Température [dég. C]')

ax.plot(t[0], t[1])  # plot t[1] (tempe) as a function of t[0] (hour)

# Add meteo icon to plot
icon = BytesIO(urlopen(day['icon_big']).read())  # Open weather icon

axicon = fig.add_axes([0.8, 0.8, 0.15, 0.15])
img = mpimg.imread(icon)  # initialise image
axicon.set_xticks([])  # Remove axes ticks
axicon.set_yticks([])
axicon.imshow(img)  # trigger the image show

plt.show()  # trigger the figure display
